clear all
clc
close all
set(0,'DefaultFigureWindowStyle','docked');

dbstop if error
whos

width = 3;     % Width in inches
height = 3;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 16;      % Fontsize
lw = 2.5;      % LineWidth
msz = 8;       % MarkerSize

% The properties we've been using in the figures
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'DefaultAxesFontSize',fsz)
% Set the default Size for display
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);

% Set the defaults for saving/printing to a file
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize');
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);


%% KINKED-DEMAND (turned quarterly)
load('shock')
Css          =ts.C(timeshock1-1);
ykinkmonth   =100*(log(ts.C(timeshock1:timeshock1+12*5-1))-log(Css));
% Turn quarterly
ykinkmatrix  =reshape(ykinkmonth,3,4*5);
ykink        =mean(ykinkmatrix);


%% CALVO (quarterly calibration)
beta     =0.99;
theta    =2/3;
kappa    =(1-theta)*(1-beta*theta)/theta;
quadra   =[beta;-(1+beta+kappa);1];
lambdas  =roots(quadra);
lambda   =lambdas(2);

quarter  =0:4*5-1;
ycalvo   =lambda.^(quarter+1);

%% FIGURE
figure
plot(quarter,ykink)
hold on
plot(quarter,ycalvo,'--')
axis([0 length(quarter) 0 1])
xlabel('Horizon (quarters)')
ylabel('\Delta ln(C) (%)')
axis([-Inf inf -0.1 1])
legend({'Kinked-demand model','Calvo model'})
set(gcf,'papersize',[11 8.5]); 
set(gcf, 'PaperPosition', [0 0 11 8.5]);
print(gcf,'-dpdf','IRF.pdf');