clear all
clc
close all
set(0,'DefaultFigureWindowStyle','docked');

dbstop if error
whos

width = 3;     % Width in inches
height = 3;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 16;      % Fontsize
lw = 2.5;      % LineWidth
msz = 8;       % MarkerSize

% The properties we've been using in the figures
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'DefaultAxesFontSize',fsz)
% Set the default Size for display
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);

% Set the defaults for saving/printing to a file
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize');
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);


%% 1. SRPC, LRPC
load('srpc')
load('lrpc')

figure
plot(outputmean,inflationlist,'b--')
hold on
plot(Css,inflationlist,'b','Linewidth',2)
hold on
scatter(outputmean(13),2,'+b','Linewidth',2)
vline(1/M(param.theta+param.alpha),'r--')
vline(1/M(param.theta+param.alpha*(1-param.lambda)),'m:')
xlabel('Output C')
ylabel('Inflation \Pi (%)')
legend({'Short-Run PC','Long-Run PC'},'Location','northwest')
set(gcf,'papersize',[11 8.5]); 
set(gcf, 'PaperPosition', [0 0 11 8.5]);                                   
print(gcf,'-dpdf','SRLRPC.pdf');

%% 2. Steady-state x distribution
clear all
load('lrpc')

figure
subplot(2,1,1)
plot(supportxi(9,:)',densityxi(9,:)','r:')
hold on
plot(supportxi(11,:)',densityxi(11,:)','b','Linewidth',2)
hold on
plot(supportxi(13,:)',densityxi(13,:)','b--')
vline(1/M(param.theta+param.alpha),'r--')
vline(1/M(param.theta+param.alpha*(1-param.lambda)),'m:')
xlabel('x_i')
set(gca,'YTickLabel',[]);
legend({'\Pi=-2%','\Pi=0%','\Pi=2%'},'Location', 'NorthWest')
axis tight
title('Steady-state cross-sectional distribution of X_i')

subplot(2,1,2)
plot(supportPiW(9,:)',densityPiW(9,:)','r:')
hold on
plot(supportPiW(11,:)',densityPiW(11,:)','b')
hold on
plot(supportPiW(13,:)',densityPiW(13,:)','b--')
xlabel('P_i/W')
set(gca,'YTickLabel',[]);
axis tight
title('Steady-state cross-sectional distribution of P_i/W')
set(gcf,'papersize',[11 8.5]); 
set(gcf, 'PaperPosition', [0 0 11 8.5]);                                   
print(gcf,'-dpdf','distributionsxiPiW.pdf');