clear all
clc
close all
set(0,'DefaultFigureWindowStyle','docked');

dbstop if error
whos

width = 3;     % Width in inches
height = 3;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 16;      % Fontsize
lw = 1.5;      % LineWidth
msz = 8;       % MarkerSize

% The properties we've been using in the figures
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'DefaultAxesFontSize',fsz)
% Set the default Size for display
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);

% Set the defaults for saving/printing to a file
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize');
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);

%set(0,'defaulttextinterpreter','tex')

%% 1. Calibration
param.alpha      =6;
param.theta      =1;
param.lambda     =0.5;

Mhigh =M(param.theta+param.alpha*(1-param.lambda));
Mlow  =M(param.theta+param.alpha);
C     =1;

br               =@(P)bestresponse(P,C,param);

figure
fplot(@(P)P,[1,1.5],'k--')
hold on
fplot(br,[1,1.5],'b')
set(gca,'xtick',[])
set(gca,'ytick',[])
vline(Mlow*C,'r--')
text(Mlow*C-0.03,0.95, 'M(\alpha+\theta) W/A_i','Interpreter','Tex','Fontsize',16,'Color','r')
vline(Mhigh*C,'m:')
text(Mhigh*C-0.03,0.95, 'M(\alpha(1-\lambda)+\theta) W/A_i','Interpreter','Tex','Fontsize',16,'Color','m')
xlabel('P_i')
ylabel('P^k')
legend({'45 line', 'Best-response'},'Location','Northwest')
set(gcf,'papersize',[11 8.5]); 
set(gcf, 'PaperPosition', [0 0 11 8.5]);
print(gcf,'-dpdf','convergence.pdf');
