clear all
clc
close all
set(0,'DefaultFigureWindowStyle','docked');

dbstop if error
whos

width = 3;     % Width in inches
height = 3;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 16;      % Fontsize
lw = 2.5;      % LineWidth
msz = 8;       % MarkerSize


% The properties we've been using in the figures
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'DefaultAxesFontSize',fsz)
% Set the default Size for display
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);

% Set the defaults for saving/printing to a file
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize');
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);

rng(59767921)

%% 1. Calibration

periodicity      =12; % for monthly calibration
param.alpha      =6;
param.theta      =1;
param.lambda     =0.5;
param.mu         =0.02/periodicity;
param.sigmaem    =0;
param.sigmaa     =0.075;
param.rhoa       =0.8^(1/periodicity);
param.sigmaea    =param.sigmaa*sqrt(1-param.rhoa^2);
T                =periodicity*5000;
Tshort           =periodicity*10;
q                =@(x)q(x,param);

%% 2. Simulations
xss             =0.5*(1/M(param.alpha+param.theta)+1/M(param.alpha*(1-param.lambda)+param.theta));
W0              =1;

epsilonm        =normrnd(param.mu,param.sigmaem,T,1);
ts.Wlog         =log(W0)+cumsum(epsilonm);
ts.W            =exp(1).^ts.Wlog;
epsilonai       =normrnd(0,param.sigmaea,T,1);

ts.Ailog        =zeros(T,1);
ts.Ailog(1)     =epsilonai(1);
for t=2:T
    ts.Ailog(t) =param.rhoa*ts.Ailog(t-1)+epsilonai(t);
end
ts.Ai           =exp(1).^ts.Ailog;
ts.Xi           =ts.W./ts.Ai;
ts.Pi           =simulationi(ts.Xi,q,1/xss);

%% 3. Sample time-series
figure
plot(ts.Pi(1:Tshort),'+b')
hold on
plot(M(param.alpha+param.theta)*ts.Xi(1:Tshort,1),'r--')
hold on
plot(M(param.alpha*(1-param.lambda)+param.theta)*ts.Xi(1:Tshort,1),'m:')
xlabel('Time (months)')
legend({'P_i','M(\alpha+\theta)W/A_i','M(\alpha (1-\lambda)+\theta)W/A_i'},'Location', 'NorthWest')
axis tight
set(gcf,'papersize',[11 8.5]); 
set(gcf, 'PaperPosition', [0 0 11 8.5]);
print(gcf,'-dpdf','individualprice.pdf');


%% 4. Hazard function
age     =zeros(length(ts.Pi),1);
age(1)  =1; %age is how many periods price has last; at least one period
for t=2:length(ts.Pi)
    if ts.Pi(t)==ts.Pi(t-1)
        age(t)=age(t-1)+1;
    else
        age(t)=1;
    end
end

agenext         =age(2:end);
age             =age(1:end-1);
changedummy     =agenext==1;

hazard          =zeros(max(age),1);
for a=1:length(hazard)
    hazard(a)   =sum(changedummy.*(age==a))/sum(age==a);
end

horizon               =min(max(age),24);
figure
plot(1:horizon,hazard(1:horizon))
xlabel('Price age (months)')
ylabel('Probability of change')
axis([1 horizon 0 0.6])
set(gcf,'papersize',[11 8.5]); 
set(gcf, 'PaperPosition', [0 0 11 8.5]);
print(gcf,'-dpdf','hazard.pdf');