clc
close all
set(0,'DefaultFigureWindowStyle','docked');

dbstop if error
%whos

width = 3;     % Width in inches
height = 3;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 16;      % Fontsize
lw = 2.5;      % LineWidth
msz = 8;       % MarkerSize


% The properties we've been using in the figures
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'DefaultAxesFontSize',fsz)
% Set the default Size for display
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);

% Set the defaults for saving/printing to a file
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize');
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);


%% 1. Calibration

param.alpha      =6;
param.theta      =1;
param.lambda     =0.5;
param.supere     =5;
e                =param.alpha+param.theta;
M                =e/(e-1);
c                =1/M; % = value at equilibrium

sharefi           =@(pk)nu(pk,param.alpha);
shareu            =@(pk)su(pk,param.alpha);  
share             =@(pk)(1-param.lambda)*sharefi(pk)+param.lambda*shareu(pk);
demand            =@(pk)share(pk)*pk^(-param.theta);
profits           =@(pk)(pk-c)*demand(pk);

demandfi          =@(pk)nu(pk,param.alpha)*pk^(-param.theta);
profitsfi         =@(pk)(pk-c)*demandfi(pk);

demandCES         =@(pk)pk^(-e);
profitsCES        =@(pk)(pk-c)*demandCES(pk);

%% Plot profits
figure
fplot(profits,[c,1.3],'b-')
hold on
[xx1,yy1]=fplot(profitsfi,[c,1.3],'b-');
plot(xx1,yy1,'b-','Linewidth',1.5)
hold on
fplot(profitsCES,[c,1.3],'k--')
hold on
param.supere      =5;
demandKW          =@(pk)(1-param.supere*log(pk))^(e/param.supere)*(pk<exp(1/param.supere));
profitsKW         =@(pk)(pk-c)*demandKW(pk);
fplot(profitsKW,[c,1.3],'r-.')
hold on
param.supere      =10;
demandKW          =@(pk)(1-param.supere*log(pk))^(e/param.supere)*(pk<exp(1/param.supere));
profitsKW         =@(pk)(pk-c)*demandKW(pk);
fplot(profitsKW,[c,1.3],'r:')
xlabel('p_k')
ylabel('\Pi_k')
legend({'Kinked Demand','Full Information','CES Demand (Superelasticity=0)','Quasi-Kinked Demand, Superelasticity=5','Quasi-Kinked Demand, Superelasticity=10'})
set(gcf,'papersize',[16 8.5]); 
set(gcf, 'PaperPosition', [0 0 16 8.5]);
print(gcf,'-dpdf','klenowwillis.pdf');