clear all
clc
close all
set(0,'DefaultFigureWindowStyle','docked');

dbstop if error
whos

width = 3;     % Width in inches
height = 3;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 16;      % Fontsize
lw = 2.5;      % LineWidth
msz = 8;       % MarkerSize

% The properties we've been using in the figures
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'DefaultAxesFontSize',fsz)

% Set the default Size for display
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);

% Set the defaults for saving/printing to a file
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize');
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);

%% 1. Calibration
param.alpha      =6;
param.theta      =1;
param.lambda     =0.5;

%% 1. Market share functions
sharefi          =@(pk)nu(pk,param.alpha);
shareu           =@(pk)su(pk,param.alpha);  
share            =@(pk)(1-param.lambda)*sharefi(pk)+param.lambda*shareu(pk);

figure
subplot(1,2,1)
fplot(shareu,[0.5,1.5],'Linewidth',2.5)
hold on
fplot(sharefi,[0.5,1.5],'--','Linewidth',2.5)
xlabel('p^k')
title('Market share among uninformed s^u')
subplot(1,2,2)
fplot(share,[0.5,1.5],'Linewidth',2.5)
hold on
fplot(sharefi,[0.5,1.5],'--','Linewidth',2.5)
xlabel('p^k')
title('Total market share s')
legend({'Asymmetric information','Full-information'})
set(gcf,'papersize',[11 5.5]); 
set(gcf, 'PaperPosition', [0 0 11 5.5]);                                   
print(gcf,'-dpdf','skink.pdf');

%% 2. q pricing function
xvalues = (0.65:0.001:0.95);
qvalues = zeros(length(xvalues),1);
for i=1:length(xvalues)
qvalues(i) = q(xvalues(i),param);
end
markup      =@(x,param)q(x,param)/x;

figure
subplot(1,2,1)
plot(xvalues,qvalues,'Linewidth',2.5)
hold on
fplot(@(x)M(param.alpha+param.theta)*x,[0.65,0.95],'r--','Linewidth',2.5)
hold on
fplot(@(x)M(param.alpha*(1-param.lambda)+param.theta)*x,[0.65,0.95],'m:','Linewidth',2.5)
axis([0.65 0.95 0.7 1.3])
xlabel('X=W/(AP_{-1})')
ylabel('P/P_{-1}')
legend({'Pricing function q','M(\alpha+\theta) X','M(\alpha(1-\lambda)+\theta) X'})
title('Pricing function')
subplot(1,2,2)
fplot(@(x)markup(x,param),[0.65,0.95],'Linewidth',2.5)
hold on
fplot(@(x)M(param.alpha+param.theta),[0.65,0.95],'r--','Linewidth',2.5)
hold on
fplot(@(x)M(param.alpha*(1-param.lambda)+param.theta),[0.65,0.95],'m:','Linewidth',2.5)
xlabel('X=W/(AP_{-1})')
ylabel('Markup')
axis([0.65 0.95 1.1 1.4])
legend({'Markup function','M(\alpha+\theta)','M(\alpha(1-\lambda)+\theta)'})
title('Markup function')
set(gcf,'papersize',[11 8.5]); 
set(gcf, 'PaperPosition', [0 0 11 8.5]);
print(gcf,'-dpdf','pricingmarkupfunction.pdf');
