clear all
clc
close all
set(0,'DefaultFigureWindowStyle','docked');

dbstop if error
whos


%% 1. Calibration

periodicity      =12; %for monthly

param.alpha      =6;
param.theta      =1;
param.lambda     =0.5;
param.mu         =0.02/periodicity;
param.sigmaem    =0;
param.sigmaa     =0.075;
param.rhoa       =0.8^(1/periodicity);
param.sigmaea    =param.sigmaa*sqrt(1-param.rhoa^2);
param.sigmae     =sqrt(param.sigmaem^2+param.sigmaea^2);
T                =periodicity*15;
S                =100000;
q                =@(x)q(x,param);

%% 2. Simulations
xss             =0.5*(1/M(param.alpha+param.theta)+1/M(param.alpha*(1-param.lambda)+param.theta));
W0              =1;
epsilonm        =normrnd(param.mu,param.sigmaem,T,1);

timeshock1       =periodicity*10;
epsilonm(timeshock1)=epsilonm(timeshock1)+0.01;

ts.Wlog         =log(W0)+cumsum(epsilonm);
ts.W            =exp(1).^ts.Wlog;
epsilonai       =normrnd(0,param.sigmaea,T,S);
RHO             =eye(T)+diag(-param.rhoa*ones(T-1,1),-1);
for i=1:S
   ts.Ailog(:,i)=RHO\epsilonai(:,i);
end
ts.Ai           =exp(1).^ts.Ailog;
ts.Xi           =repmat(ts.W,1,S)./ts.Ai;

for s=1:S
    [Pi,xi]     =simulationi(ts.Xi(:,s),q,1/xss);
    ts.Pi(:,s)  =Pi;
    ts.xi(:,s)  =xi;
end

ts.P            =pricelevel(ts.Pi,param.theta);
ts.C            =ts.W./ts.P;

tsmacro.P=ts.P;
tsmacro.C=ts.C;
tsmacro.W=ts.W;

save('shock');