clear all
clc
close all
set(0,'DefaultFigureWindowStyle','docked');

dbstop if error
whos

%% 1. Calibration

periodicity      =12; % for monthly

param.alpha      =6;
param.theta      =1;
param.lambda     =0.5;
param.sigmaem    =0;
param.sigmaa     =0.075;
param.rhoa       =0.8^(1/periodicity);
param.sigmaea    =param.sigmaa*sqrt(1-param.rhoa^2);
T                =periodicity*15;
S                =100000;
q                =@(x)q(x,param);

%% Simualtion Ai
xss             =0.5*(1/M(param.alpha+param.theta)+1/M(param.alpha*(1-param.lambda)+param.theta));
epsilonai       =normrnd(0,param.sigmaea,T,S);
RHO             =eye(T)+diag(-param.rhoa*ones(T-1,1),-1);
for i=1:S
   ts.Ailog(:,i)=RHO\epsilonai(:,i);
end
ts.Ai           =exp(1).^ts.Ailog;
A               =exp(mean(ts.Ailog(end,:)));

%% Simulations for different mu
W0              =1;
inflationlist   =(-10:1:10)';
mulist          =inflationlist/100/periodicity;

Css             =zeros(length(mulist),1);
densityxi       =zeros(length(mulist),100);
supportxi       =zeros(length(mulist),100);
densityPiW      =zeros(length(mulist),100);
supportPiW      =zeros(length(mulist),100);
for m=1:length(mulist)
m
mu              =mulist(m);
epsilonm        =normrnd(mu,param.sigmaem,T,1);
ts.Wlog         =log(W0)+cumsum(epsilonm);
ts.W            =exp(1).^ts.Wlog;
ts.Xi           =repmat(ts.W,1,S)./ts.Ai;
for s=1:S
    [Pi,xi]     =simulationi(ts.Xi(:,s),q,1/xss);
    ts.Pi(:,s)  =Pi;
    ts.xi(:,s)  =xi;
end
ts.PiW          =ts.Pi./repmat(ts.W,1,S);
ts.P            =pricelevel(ts.Pi,param.theta);
ts.C            =ts.W./ts.P;
[densityx,supportx]       =ksdensity(ts.xi(end,:));
[densityPW,supportPW]     =ksdensity(ts.PiW(end,:));

Css(m)          =ts.C(end);
densityxi(m,:)  =densityx;
supportxi(m,:)  =supportx;
densityPiW(m,:) =densityPW; 
supportPiW(m,:) =supportPW;
end

save('lrpc','inflationlist','periodicity','param','Css','densityxi','supportxi','densityPiW','supportPiW','A')