clear all
clc
close all
set(0,'DefaultFigureWindowStyle','docked');

dbstop if error
whos

%% 1. Calibration

rng(1234)

periodicity      =12; %for monthly

param.alpha      =6;
param.theta      =1;
param.lambda     =0.5;
param.mu         =0.02/periodicity;
param.sigmaem    =0;
param.sigmaa     =0.075;
param.rhoa       =0.8^(1/periodicity);
param.sigmaea    =param.sigmaa*sqrt(1-param.rhoa^2);
T                =periodicity*11;
S                =100000;
q                =@(x)q(x,param);

%% Simualtion Ai
xss             =0.5*(1/M(param.alpha+param.theta)+1/M(param.alpha*(1-param.lambda)+param.theta));
epsilonai       =normrnd(0,param.sigmaea,T,S);
RHO             =eye(T)+diag(-param.rhoa*ones(T-1,1),-1);
for i=1:S
   ts.Ailog(:,i)=RHO\epsilonai(:,i);
end
ts.Ai           =exp(1).^ts.Ailog;
A               =exp(mean(ts.Ailog(end,:)));

%% 1. Simulation until T-periodicity (done until T actually, then overwrite)
W0              =1;
epsilonm        =normrnd(param.mu,param.sigmaem,T,1);
ts.Wlog         =log(W0)+cumsum(epsilonm);
ts.W            =exp(1).^ts.Wlog;
ts.Xi           =repmat(ts.W,1,S)./ts.Ai;
for s=1:S
[Pi,xi]     =simulationi(ts.Xi(:,s),q,1/xss);
ts.Pi(:,s)  =Pi;
ts.xi(:,s)  =xi;
end
ts.P            =pricelevel(ts.Pi,param.theta);
ts.C            =ts.W./ts.P;
ts.PiW          =ts.Pi./repmat(ts.W,1,S);
ts.PiP          =ts.Pi./repmat(ts.P,1,S);

Mlow            =M(param.alpha+param.theta);
Mhigh           =M(param.alpha*(1-param.lambda)+param.theta);

%% 2. Simulations last periodicity periods for different mu
inflationlist   =(-10:1:10)';
mulist          =inflationlist/100/periodicity;

output          =zeros(length(mulist),periodicity);
densityxi       =zeros(length(mulist),100);
supportxi       =zeros(length(mulist),100);
densityPiW      =zeros(length(mulist),100);
supportPiW      =zeros(length(mulist),100);

last.Ai         =ts.Ai(end-periodicity+1:end,:);
    
for m=1:length(mulist)
    inflation       =mulist(m)+1;
    last.PiPlag     =zeros(periodicity+1,S);
    last.PiPlag(1,:)=ts.PiP(end-periodicity,:);
    last.Pilag      =zeros(periodicity+1,S);
    last.Pilag(1,:) =ts.Pi(end-periodicity,:);
    last.Plag       =zeros(periodicity+1,1);
    last.Plag(1)    =ts.P(end-periodicity);
    last.inflation  =zeros(periodicity,1);
    for t=1:periodicity
        [m,t]
        distrib.Zi      =1./(last.Ai(t,:).*last.PiPlag(t,:));
        RHSofC          =@(C)RHS(distrib,C,inflation,Mhigh, Mlow);
        output(m,t)     =fsolve(@(C)RHSofC(C)-log(inflation),1);
        distribxi       =inflation*output(m,t)*distrib.Zi;
        for s=1:S
            last.Pilag(t+1,s) =q(distribxi(s))*last.Pilag(t,s);
            last.PiPlag(t+1,s)=q(distribxi(s))*last.PiPlag(t,s)/inflation;
        end
        last.Plag(t+1)  =pricelevel(last.Pilag(t+1,:),param.theta);
        last.inflation(t)=last.Plag(t+1)/last.Plag(t);
    end
    % Last period: densities
    distribPiW              =last.Pilag(end,:)/ts.W(end);
    [densityx,supportx]     =ksdensity(distribxi);
    [densityPW,supportPW]   =ksdensity(distribPiW);
    densityxi(m,:)  =densityx;
    supportxi(m,:)  =supportx;
    densityPiW(m,:) =densityPW; 
    supportPiW(m,:) =supportPW;
end
outputmean =mean(output,2);

save('srpc','inflationlist','periodicity','param','output','outputmean','densityxi','supportxi','densityPiW','supportPiW','A')